/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */
package org.apache.bookkeeper.http.service;

import org.apache.bookkeeper.http.HttpServer;

/**
 * A wrapper class that wrap the result from service, which
 * can then be parsed into http response.
 */
public class HttpServiceResponse {
    private String body;
    private String contentType;
    private HttpServer.StatusCode code = HttpServer.StatusCode.OK;

    public HttpServiceResponse() {}

    public HttpServiceResponse(String body, HttpServer.StatusCode code) {
        this.body = body;
        this.code = code;
    }

    public String getBody() {
        return body;
    }

    public String getContentType() {
        return contentType;
    }

    public int getStatusCode() {
        return code.getValue();
    }

    public HttpServiceResponse setBody(String body) {
        this.body = body;
        return this;
    }

    public HttpServiceResponse setContentType(String contentType) {
        this.contentType = contentType;
        return this;
    }

    public HttpServiceResponse setCode(HttpServer.StatusCode code) {
        this.code = code;
        return this;
    }
}
